misc_gui.c
changeset 1274 1605774b5589
parent 1176 46d14419c1dd
child 1299 0a6510cc889b
--- a/misc_gui.c	Thu Feb 03 18:20:43 2005 +0000
+++ b/misc_gui.c	Thu Feb 03 19:23:06 2005 +0000
@@ -1259,8 +1259,8 @@
 		}
 		break;
 	case WE_DESTROY:
-		// pause is only used in single-player, non-editor mode
-		if(!_networking && (_game_mode != GM_EDITOR))
+		// pause is only used in single-player, non-editor mode, non menu mode
+		if(!_networking && (_game_mode != GM_EDITOR) && (_game_mode != GM_MENU))
 			DoCommandP(0, 0, 0, NULL, CMD_PAUSE);
 		_query_string_active = false;
 		FiosFreeSavegameList();
@@ -1350,7 +1350,8 @@
 		strcpy(_edit_str_buf, "UNNAMED");
 	}
 
 	// pause is only used in single-player, non-editor mode
 	if(_game_mode != GM_MENU && !_networking && _game_mode != GM_EDITOR)
 		DoCommandP(0, 1, 0, NULL, CMD_PAUSE);
@@ -1350,7 +1350,8 @@
 	}
 
-	// pause is only used in single-player, non-editor mode
+	// pause is only used in single-player, non-editor mode, non-menu mode. It
+	// will be unpaused in the WE_DESTROY event handler.
 	if(_game_mode != GM_MENU && !_networking && _game_mode != GM_EDITOR)
 		DoCommandP(0, 1, 0, NULL, CMD_PAUSE);